Add members to the load balancer pool.

| IP Address | Subnet | Port | Weight |
--- | --- | --- | --- | --- | ---
{$ ::trCtrl.helpText.noneAllocText $}
| {$ row.address.ip $} | {$ ctrl.getSubnetName(row) $} |  |  | Remove
Monitor Address Monitor Port
Add external member

Name | IP Address |
--- | --- | ---
{$ ::trCtrl.helpText.noneAvailText $}
{$ ::row.name $} | {$ row.address.ip $} {$ ctrl.addressPopoverTarget(row) $} | Add